scipy.sparse.dok
================

.. automodule:: scipy.sparse.dok

   
   
   .. rubric:: Functions

   .. autosummary::
   
      getdtype
      isdense
      isintlike
      isscalarlike
      isshape
      isspmatrix
      isspmatrix_dok
      upcast
   
   

   
   
   .. rubric:: Classes

   .. autosummary::
   
      dok_matrix
      izip
      spmatrix
   
   

   
   
   